from setuptools import setup
import os

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "tempowork",
    version = "0.0.6",
    author = "Ali Jazayeri",
    author_email = "ali.jazayeri@drexel.edu",
    description = ("A library for mining temporal networks where time is represented as a continuous dimension!"),
    license = "MIT",
    keywords = "subgraph mining; temporal networks",
    url = "https://github.com/alijazayeri/tempowork",
    py_modules=['tempowork'],
    long_description=read('README.rst'),
long_description_content_type='text/x-rst'
)